<template>
  <div class="sidebar-logo-container" :class="{ 'collapse': collapse }" :style="{ backgroundColor: sideTheme === 'theme-dark' ? variables.menuBackground : variables.menuLightBackground }">
    <transition name="sidebarLogoFade">
      <router-link v-if="collapse" key="collapse" class="sidebar-logo-link" :to="firstPage">
        <img v-if="logoImg" :src="logoImg" class="sidebar-logo" />
        <h1 v-else class="sidebar-title" :style="{ color: sideTheme === 'theme-dark' ? variables.logoTitleColor : variables.logoLightTitleColor }">{{ title }}</h1>
      </router-link>
      <router-link v-else key="expand" class="sidebar-logo-link" :to="firstPage">
        <img v-if="logoImg" :src="logoImg" class="sidebar-logo" />
        <h1 class="sidebar-title" :style="{ color: sideTheme === 'theme-dark' ? variables.logoTitleColor : variables.logoLightTitleColor }">{{ title }}</h1>
      </router-link>
    </transition>
  </div>
</template>

<script setup>
import variables from '@/assets/styles/variables.module.scss'
import logo from '@/assets/logo/logo2.png'
import useSettingsStore from '@/store/modules/settings'
import {onMounted, ref} from "vue";
import Cookies from "js-cookie";
defineProps({
  collapse: {
    type: Boolean,
    required: true
  }
})
const logoImg = ref('')
const firstPage = ref("");
onMounted(() => {
    const routers = JSON.parse(Cookies.get('routers')) ;
    if(routers[0].children){
      firstPage.value = routers[0].path + '/' + routers[0].children[0].path;
    }else {
      firstPage.value = routers[0].path;
    }

  console.log(routers,'firstPage.value')
    console.log(firstPage.value,'firstPage.value')
    if(Cookies.get('configInfo')){
      const config = JSON.parse(Cookies.get('configInfo'))
      if(config && config.logoPath != ''){
        logoImg.value = import.meta.env.VITE_APP_BASE_API + "/" +  config.logoPath
      }else {
        logoImg.value = logo
      }
    }else {
      logoImg.value = logo
    }


});
const title = import.meta.env.VITE_APP_TITLE;
const settingsStore = useSettingsStore();
const sideTheme = computed(() => settingsStore.sideTheme);
</script>

<style lang="scss" scoped>
.sidebarLogoFade-enter-active {
  transition: opacity 1.5s;
}

.sidebarLogoFade-enter,
.sidebarLogoFade-leave-to {
  opacity: 0;
}

.sidebar-logo-container {
  position: relative;
  width: 100%;
  height: 50px;
  line-height: 50px;
  background: #2b2f3a;
  //text-align: center;
  margin-left: 20%;
  overflow: hidden;

  & .sidebar-logo-link {
    height: 100%;
    width: 100%;

    & .sidebar-logo {
      width: 32px;
      height: auto;
      vertical-align: middle;
      margin-right: 5px;
    }

    & .sidebar-title {
      display: inline-block;
      margin: 0;
      color: #fff;
      font-weight: 600;
      line-height: 50px;
      font-size: 16px;
      font-family: Avenir, Helvetica Neue, Arial, Helvetica, sans-serif;
      vertical-align: middle;
    }
  }

  &.collapse {
    .sidebar-logo {
      margin-right: 0px;
    }
  }
}
</style>
